"use strict";
/**
 * Copyright (c) Microsoft Corporation. All rights reserved.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.getCacheDataProviderServiceKey = exports.CacheDataProviderService = void 0;
var sp_core_library_1 = require("@microsoft/sp-core-library");
/**
 * The CacheDataProviderService used for injecting CacheDataprovider singelton to SPHttpClient
 *
 * @internal
 */
var CacheDataProviderService = /** @class */ (function () {
    /**
     * Initializes a new instance of the CacheDataProviderService class.
     * @param serviceScope - The service scope.
     */
    function CacheDataProviderService(serviceScope) {
        // do nothing
    }
    Object.defineProperty(CacheDataProviderService.prototype, "_provider", {
        /**
         * Gets or sets the cache data provider
         *
         * @internal
         */
        get: function () {
            return this._cacheDataProvider;
        },
        set: function (provider) {
            sp_core_library_1.Validate.isNotNullOrUndefined(provider, 'Cache provider can not be null or undefined');
            if (provider.isDisposed) {
                throw new Error('Cache provider can not be disposed');
            }
            if (this._cacheDataProvider) {
                throw new Error('Cache provider can only be set once');
            }
            this._cacheDataProvider = provider;
        },
        enumerable: false,
        configurable: true
    });
    return CacheDataProviderService;
}());
exports.CacheDataProviderService = CacheDataProviderService;
/**
 * Gets the service key.
 *
 * @internal
 */
function getCacheDataProviderServiceKey() {
    if (!CacheDataProviderService.serviceKey) {
        CacheDataProviderService.serviceKey = sp_core_library_1.ServiceKey.create('sp-http:CacheDataProvider', CacheDataProviderService);
    }
    return CacheDataProviderService.serviceKey;
}
exports.getCacheDataProviderServiceKey = getCacheDataProviderServiceKey;
//# sourceMappingURL=CacheDataProviderService.js.map