"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.shouldPrintMsalLogsToConsole = void 0;
/**
 * Used by MsalTokenProvider and MsalBrowserTokenProvider to determine whether or not
 * to print msal logs to the console. This method looks at the query parameter strings
 * and returns true if it finds 'msalLogging=true'
 *
 * This method will continue to return true until it is explicitly set to false
 * ('msalLogging=false') or until the session storage key is removed.
 *
 * @returns True if msal should print logs to the console. False by default.
 */
function shouldPrintMsalLogsToConsole() {
    var _a;
    var SESSION_STORAGE_KEY = 'spfx.msal.shouldPrintLogs';
    var QUERY_STR = 'msalLogging';
    var queryParams = new URLSearchParams(window.location.search);
    var msalLoggingQueryFlag = ((_a = queryParams.get(QUERY_STR)) === null || _a === void 0 ? void 0 : _a.toLowerCase()) || '';
    if (msalLoggingQueryFlag === 'true') {
        window.sessionStorage.setItem(SESSION_STORAGE_KEY, 'true');
    }
    else if (msalLoggingQueryFlag === 'false') {
        window.sessionStorage.removeItem(SESSION_STORAGE_KEY);
    }
    var msalLoggingStorageFlag = window.sessionStorage.getItem(SESSION_STORAGE_KEY) || '';
    var shouldPrintMsalLogs = msalLoggingQueryFlag === 'true' || msalLoggingStorageFlag === 'true';
    return shouldPrintMsalLogs;
}
exports.shouldPrintMsalLogsToConsole = shouldPrintMsalLogsToConsole;
//# sourceMappingURL=MsalUtilities.js.map